@@ -57,8 +57,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.8.1/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.8.1/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.8.3/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.8.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -549,7 +549,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.8',
  'LIBDIR': '/usr/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/lib/libffi-3.2.1/include',
+ 'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
@@ -705,7 +705,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.1',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.3',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -747,9 +747,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.1 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.3 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.1 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.3 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -761,6 +761,7 @@ build_time_vars = {'ABIFLAGS': '',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.8',
  'WINDOW_HAS_FLAGS': 1,
+ 'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
@@ -770,8 +771,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.8.1',
- 'abs_srcdir': '/build/python/src/Python-3.8.1',
+ 'abs_builddir': '/build/python/src/Python-3.8.3',
+ 'abs_srcdir': '/build/python/src/Python-3.8.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
